# Icons

## moon.svg

[Dark Mode](https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Adark_mode%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4024&icon.query=mode&icon.size=24&icon.color=%23e3e3e3)
material icon

## sun.svg

[Light Mode](https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Alight_mode%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4024&icon.query=mode&icon.size=24&icon.color=%23e3e3e3)
material icon
